/****************************************************************************
**
** Copyright (C) 2011 Takumi Asaki
** All rights reserved.
** Contact: Takumi Asaki (takumi.asaki@gmail.com)
**
** This file is part of the fontmanager application.
**
** You may use this file under the terms of the BSD license as follows:
**
** "Redistribution and use in source and binary forms, with or without
** modification, are permitted provided that the following conditions are
** met:
**   * Redistributions of source code must retain the above copyright
**     notice, this list of conditions and the following disclaimer.
**   * Redistributions in binary form must reproduce the above copyright
**     notice, this list of conditions and the following disclaimer in
**     the documentation and/or other materials provided with the
**     distribution.
**   * Neither the name of Nokia Corporation and its Subsidiary(-ies) nor
**     the names of its contributors may be used to endorse or promote
**     products derived from this software without specific prior written
**     permission.
**
** THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
** "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
** LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
** A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
** OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
** SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
** LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
** DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
** THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
** (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
** OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE."
**
****************************************************************************/

// import QtQuick 1.0 // to target S60 5th Edition or Maemo 5
import QtQuick 1.1
import com.nokia.meego 1.0
import 'UIConstants.js' as UI

Page {
    id: editorTabPage
    tools: editorTabTool

    property string currentPriority

    TabGroup {
        id: editFontsConfTab

        currentTab: sansSerifTab

        FontsConfEditor {
            id: sansSerifTab
            family: "sans-serif"
            familyName: qsTr("Sans Serif")
            editorController: controller.editorController(family)
        }

        FontsConfEditor {
            id: serifTab
            family: "serif"
            familyName: qsTr("Serif")
            editorController: controller.editorController(family)
        }

        FontsConfEditor {
            id: monospaceTab
            family: "monospace"
            familyName: qsTr("Monospace")
            editorController: controller.editorController(family)
        }

    }

    MultiSelectionDialog {
        id: selectInstallFamily
        model: installableFamilyListModel
        acceptButtonText: qsTr("Add")
        titleText: qsTr("Add Family for %1").arg(editFontsConfTab.currentTab.familyName)
        onAccepted: {
            for (var i = 0; i < selectedIndexes.length; i++) {
                var idx = selectedIndexes[i]
                var sItem = installableFamilyListModel.get(idx)
                var tab = editFontsConfTab.currentTab
                tab.editorController.appendFamily(sItem.enfamily, currentPriority)
                tab.insertFamily(sItem.enfamily, currentPriority, sItem.systemFont)
            }
        }
    }

    ToolBarLayout {
        id: editorTabTool
        visible: true
        ToolIcon {
            platformIconId: "toolbar-back"
            onClicked: {
                if (editMenu.status !== DialogStatus.Closed)
                    editMenu.close()
                pageStack.pop()
            }
        }
        ButtonRow {
            style: TabButtonStyle { }
            TabButton {
                text: sansSerifTab.familyName
                tab: sansSerifTab
            }
            TabButton {
                text: serifTab.familyName
                tab: serifTab
            }
            TabButton {
                text: monospaceTab.familyName
                tab: monospaceTab
            }
        }
        ToolIcon {
            platformIconId: "toolbar-view-menu"
            anchors.right: (parent === undefined) ? undefined : parent.right
            onClicked: {
                if (!mainPage.enabled)
                    return
                if (editMenu.status === DialogStatus.Closed)
                    editMenu.open()
                else
                    editMenu.close()
            }
        }
    }

    Menu {
        id: editMenu
        visualParent: pageStack
        MenuLayout {
            MenuItem {
                text: qsTr("Remove current fonts config");
                enabled: !controller.isEmptyFontsConf
                onClicked: {
                    editMenu.close()
                    removeConfirmDialog.open()
                }
            }
            MenuItem {
                text: qsTr("View current fonts config");
//                enabled: controller.localFontsConfExists
                onClicked: {
                    editMenu.close()
                    pageStack.push(fontsConfViewPageComponent, { "text": controller.localFontsConf } )
                }
            }
        }
    }

    QueryDialog {
        id: removeConfirmDialog
        titleText: qsTr("Remove it?")
        message: qsTr("Existing fonts config %1 will be removed.  Are you sure?").arg(controller.localFontsConfPath)
        acceptButtonText: qsTr("OK")
        rejectButtonText: qsTr("Cancel")
        onAccepted: controller.resetLocalFontsConf()
    }

}
