/****************************************************************************
**
** Copyright (C) 2011 Takumi Asaki
** All rights reserved.
** Contact: Takumi Asaki (takumi.asaki@gmail.com)
**
** This file is part of the fontmanager application.
**
** You may use this file under the terms of the BSD license as follows:
**
** "Redistribution and use in source and binary forms, with or without
** modification, are permitted provided that the following conditions are
** met:
**   * Redistributions of source code must retain the above copyright
**     notice, this list of conditions and the following disclaimer.
**   * Redistributions in binary form must reproduce the above copyright
**     notice, this list of conditions and the following disclaimer in
**     the documentation and/or other materials provided with the
**     distribution.
**   * Neither the name of Nokia Corporation and its Subsidiary(-ies) nor
**     the names of its contributors may be used to endorse or promote
**     products derived from this software without specific prior written
**     permission.
**
** THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
** "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
** LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
** A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
** OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
** SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
** LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
** DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
** THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
** (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
** OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE."
**
****************************************************************************/

// import QtQuick 1.0 // to target S60 5th Edition or Maemo 5
import QtQuick 1.1
import com.nokia.meego 1.0
import 'UIConstants.js' as UI

Page {
    id: fontInstallPage
    tools: backToolBar

    property variant fontInfo

    signal saveProperties

    function installFont()
    {
        if (controller.fontExists(fontInfo))
            overwriteFontDialog.open()
        else
            controller.installFont(fontInfo);
    }

    Component.onDestruction: {
        if (fontInfo) {
            fontInfo.destroy()
        }
    }

    Label {
        id: pageHeader
        anchors.top: parent.top
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.margins: UI.DEFAULT_MARGIN

        horizontalAlignment: Text.AlignHCenter
        font.pixelSize: UI.FONT_LARGE
        font.bold: true
        text: qsTr("Install Font")
    }

    Flickable {
        id: view
        anchors.top: pageHeader.bottom
        anchors.bottom: parent.bottom
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.margins: UI.DEFAULT_MARGIN
        clip: true

        //        contentWidth: contentColumn.width
        contentHeight: contentColumn.height

        Column {
            id: contentColumn
            width: parent.width
            spacing: UI.DEFAULT_MARGIN

            Repeater {
                width: parent.width
                model: fontInfo.families

                delegate: Rectangle {
                    width: parent.width - 1
                    height: childrenRect.height + UI.DEFAULT_MARGIN * 2
                    border.width: 1
                    color: "transparent"
                    Column {
                        anchors.top: parent.top
                        anchors.left: parent.left
                        anchors.right: parent.right
//                        width: parent.width
                        anchors.margins: UI.DEFAULT_MARGIN
                        spacing: UI.DEFAULT_MARGIN
                        Label {
                            width: parent.width
                            text: qsTr("<b>Font Family</b>: %1").arg(modelData)
                        }
                        Label {
                            width: parent.width
                            text: qsTr("<b>Example</b>: ")
                        }
                        Label {
                            width: parent.width - UI.DEFAULT_MARGIN * 2
                            x: UI.DEFAULT_MARGIN
                            text: qsTr("The quick brown fox jumps over the lazy dog")
                            font.family: modelData
                        }
                        FontsConfProperties {
                            id: fontProp
                            width: parent.width
                            fontconf: fontInfo.fontProperty(modelData)
                            Connections {
                                target: fontInstallPage
                                onSaveProperties: {
                                    fontProp.save()
                                }
                            }
                        }
                    }
                }
            }

            Button {
                id: installButton
                text: qsTr("Install")
                anchors.horizontalCenter: parent.horizontalCenter
                onClicked: {
                    saveProperties()
                    if (!controller.fontDirExists)
                        createFontDirDialog.open()
                    else
                        installFont()
                }
            }
        }

    }

    QueryDialog {
        id: createFontDirDialog
        titleText: qsTr("Create it?")
        message: qsTr("Local fonts directory '%1' does not exists!  Create it now?").arg(controller.fontDir)
        acceptButtonText: qsTr("OK")
        rejectButtonText: qsTr("Cancel")
        onAccepted: {
            controller.createFontDir()
            installFont()
        }
    }

    QueryDialog {
        id: overwriteFontDialog
        titleText: qsTr("Overwrite it?")
        message: qsTr("Local font '%1' already exists!  Overwrite it?").arg(fontInfo.fileName)
        acceptButtonText: qsTr("OK")
        rejectButtonText: qsTr("Cancel")
        onAccepted: controller.installFont(fontInfo)
    }

}
