/****************************************************************************
**
** Copyright (C) 2011 Takumi Asaki
** All rights reserved.
** Contact: Takumi Asaki (takumi.asaki@gmail.com)
**
** This file is part of the fontmanager application.
**
** You may use this file under the terms of the BSD license as follows:
**
** "Redistribution and use in source and binary forms, with or without
** modification, are permitted provided that the following conditions are
** met:
**   * Redistributions of source code must retain the above copyright
**     notice, this list of conditions and the following disclaimer.
**   * Redistributions in binary form must reproduce the above copyright
**     notice, this list of conditions and the following disclaimer in
**     the documentation and/or other materials provided with the
**     distribution.
**   * Neither the name of Nokia Corporation and its Subsidiary(-ies) nor
**     the names of its contributors may be used to endorse or promote
**     products derived from this software without specific prior written
**     permission.
**
** THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
** "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
** LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
** A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
** OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
** SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
** LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
** DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
** THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
** (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
** OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE."
**
****************************************************************************/

// import QtQuick 1.0 // to target S60 5th Edition or Maemo 5
import QtQuick 1.1
import com.nokia.meego 1.0
import 'UIConstants.js' as UI

Page {
    id: fontsConfViewPage

    tools: backTools

    property alias text: textArea.text

    Label {
        id: pageHeader
        anchors.top: parent.top
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.margins: UI.DEFAULT_MARGIN

        horizontalAlignment: Text.AlignHCenter
        font.pixelSize: UI.FONT_LARGE
        font.bold: true
        text: qsTr("Current Fonts Config")
    }

    Rectangle {
        id: rect
        anchors.top: pageHeader.bottom
        anchors.bottom: parent.bottom
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.margins: UI.DEFAULT_MARGIN

        border.width: 1
        border.color: "gray"
        color: "transparent"

        Flickable {
            id: flickable
            anchors.fill: parent
            visible: controller.localFontsConfExists

            clip: true
            boundsBehavior: Flickable.StopAtBounds
            contentWidth: textArea.paintedWidth
            contentHeight: textArea.paintedHeight
            Text {
                id: textArea
                //        readOnly: true
                //            anchors.fill: parent
                textFormat: Text.PlainText
                font.pixelSize: UI.FONT_DEFAULT_SIZE
            }
        }

        Text {
            id: emptyText
            width: parent.width - UI.DEFAULT_MARGIN * 2
            wrapMode: Text.WrapAtWordBoundaryOrAnywhere
            anchors.centerIn: parent
            text: qsTr("No such file or directory: %1").arg(controller.localFontsConfPath)
            font.pixelSize: UI.FONT_XLARGE
            font.bold: true
            color: "gray"
            visible: !controller.localFontsConfExists
            horizontalAlignment: Text.AlignHCenter

        }
    }

    ToolBarLayout {
        id: backTools
        ToolIcon {
            platformIconId: "toolbar-back"
            onClicked: pageStack.pop()
        }
    }

}
