/****************************************************************************
**
** Copyright (C) 2011 Takumi Asaki
** All rights reserved.
** Contact: Takumi Asaki (takumi.asaki@gmail.com)
**
** This file is part of the fontmanager application.
**
** You may use this file under the terms of the BSD license as follows:
**
** "Redistribution and use in source and binary forms, with or without
** modification, are permitted provided that the following conditions are
** met:
**   * Redistributions of source code must retain the above copyright
**     notice, this list of conditions and the following disclaimer.
**   * Redistributions in binary form must reproduce the above copyright
**     notice, this list of conditions and the following disclaimer in
**     the documentation and/or other materials provided with the
**     distribution.
**   * Neither the name of Nokia Corporation and its Subsidiary(-ies) nor
**     the names of its contributors may be used to endorse or promote
**     products derived from this software without specific prior written
**     permission.
**
** THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
** "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
** LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
** A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
** OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
** SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
** LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
** DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
** THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
** (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
** OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE."
**
****************************************************************************/

import QtQuick 1.1
import com.nokia.meego 1.0
import com.nokia.extras 1.1
import 'UIConstants.js' as UI

Page {
    id: mainPage
    tools: mainTools

    enabled: !controller.working
    opacity: enabled ? 1.0 : 0.5

    Label {
        id: pageHeader
        anchors.top: parent.top
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.margins: UI.DEFAULT_MARGIN

        horizontalAlignment: Text.AlignHCenter
        font.pixelSize: UI.FONT_LARGE
        font.bold: true
        text: qsTr("Installed Fonts")
    }

    Connections {
        target: controller
        onClearInstalledFontList: {
            installedFontList.clear()
        }
        onAppendInstalledFont: {
            installedFontList.append({ "title": family, "subtitle": fullname })
        }
    }

    ListModel {
        id: installedFontList
    }

    ListView {
        id: listView
        anchors.top: pageHeader.bottom
        anchors.bottom: parent.bottom
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.margins: UI.DEFAULT_MARGIN
        clip: true

        model: installedFontList

        delegate: ListDelegate {
            onClicked: {
                if (!mainPage.enabled)
                    return
                if (mainMenu.status !== DialogStatus.Closed)
                    mainMenu.close()
                pageStack.push(installedFontInfoPageComponent, { "fontInfo": controller.fontInfo(title, subtitle) } );
            }
        }

    }

    Text {
        id: warningText
        width: parent.width - UI.DEFAULT_MARGIN * 2
        wrapMode: Text.WrapAtWordBoundaryOrAnywhere
        anchors.centerIn: parent
        text: qsTr("No Fonts Installed")
        font.pixelSize: UI.FONT_XLARGE
        font.bold: true
        color: "gray"
        visible: listView.count == 0
        horizontalAlignment: Text.AlignHCenter
    }

    BusyIndicator {
        id: busyIndicator
        anchors.centerIn: parent
        platformStyle: BusyIndicatorStyle { size: "large" }
        running: !parent.enabled
        visible: running
    }

    Component {
        id: installedFontInfoPageComponent
        InstalledFontInfoPage { }
    }

    Component {
        id: fontsConfViewPageComponent
        FontsConfViewPage { }
    }

    Component {
        id: editFontsConfPageComponent
        EditFontsConfPage {}
    }

    ToolBarLayout {
        id: mainTools
        visible: true
        ToolIcon {
            platformIconId: "toolbar-add"
            onClicked: {
                if (!mainPage.enabled)
                    return
                if (mainMenu.status !== DialogStatus.Closed)
                    mainMenu.close()
                pageStack.push(fontSelectPage)
            }
        }
        ToolIcon {
            platformIconId: "toolbar-settings"
            enabled: (installedFontList.count > 0)
            opacity: enabled ? 1.0 : 0.5
            onClicked: {
                if (!mainPage.enabled)
                    return
                if (mainMenu.status !== DialogStatus.Closed)
                    mainMenu.close()
                pageStack.push(editFontsConfPageComponent)
            }
        }

        ToolIcon {
            platformIconId: "toolbar-view-menu"
            anchors.right: (parent === undefined) ? undefined : parent.right
            onClicked: {
                if (!mainPage.enabled)
                    return
                if (mainMenu.status === DialogStatus.Closed)
                    mainMenu.open()
                else
                    mainMenu.close()
            }
        }
    }

    Menu {
        id: mainMenu
        visualParent: pageStack
        MenuLayout {
            MenuItem {
                text: qsTr("About")
                onClicked: aboutDialog.open()
            }
            MenuItem {
                text: qsTr("Create Recommended Settings");
                enabled: (installedFontList.count > 0)
                onClicked: {
                    if (mainMenu.status !== DialogStatus.Closed)
                        mainMenu.close()
                    if (controller.localFontsConfExists)
                        createConfirmDialog.open()
                    else
                        controller.createRecommendedSettings()
                }
            }
        }
    }

    QueryDialog {
        id: createConfirmDialog
        titleText: qsTr("Replace it?")
        message: qsTr("Existing %1 will be replaced by recommended settings.  Are you sure?").arg(controller.localFontsConfPath)
        acceptButtonText: qsTr("OK")
        rejectButtonText: qsTr("Cancel")
        onAccepted: controller.createRecommendedSettings()
    }

    QueryDialog {
        id: aboutDialog
        titleText: qsTr("Font Manager for N9")
        message: qsTr("Version: %1\nAuthor: Takumi Asaki <takumi.asaki@gmail.com>\n\nApplication Icon is created by hirao").arg(controller.version)
        acceptButtonText: qsTr("OK")
    }
}
